==> v21.04.tar.gz: bookstack/resources/lang/ca/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Cancel·la',
    'confirm' => 'D\'acord',
    'back' => 'Endarrere',
    'save' => 'Desa',
    'continue' => 'Continua',
    'select' => 'Selecciona',
    'toggle_all' => 'Commuta-ho tot',
    'more' => 'Més',

    // Form Labels
    'name' => 'Nom',
    'description' => 'Descripció',
    'role' => 'Rol',
    'cover_image' => 'Imatge de portada',
    'cover_image_description' => 'Aquesta imatge hauria de fer aproximadament 440x250 px.',
    
    // Actions
    'actions' => 'Accions',
    'view' => 'Visualitza',
    'view_all' => 'Visualitza-ho tot',
    'create' => 'Crea',
    'update' => 'Actualitza',
    'edit' => 'Edita',
    'sort' => 'Ordena',
    'move' => 'Mou',
    'copy' => 'Copia',
    'reply' => 'Respon',
    'delete' => 'Suprimeix',
    'delete_confirm' => 'Confirma la supressió',
    'search' => 'Cerca',
    'search_clear' => 'Esborra la cerca',
    'reset' => 'Reinicialitza',
    'remove' => 'Elimina',
    'add' => 'Afegeix',
    'fullscreen' => 'Pantalla completa',

    // Sort Options
    'sort_options' => 'Opcions d\'ordenació',
    'sort_direction_toggle' => 'Commuta la direcció de l\'ordenació',
    'sort_ascending' => 'Ordre ascendent',
    'sort_descending' => 'Ordre descendent',
    'sort_name' => 'Nom',
    'sort_default' => 'Default',
    'sort_created_at' => 'Data de creació',
    'sort_updated_at' => 'Data d\'actualització',

    // Misc
    'deleted_user' => 'Usuari eliminat',
    'no_activity' => 'No hi ha activitat',
    'no_items' => 'No hi ha cap element',
    'back_to_top' => 'Torna a dalt',
    'toggle_details' => 'Commuta els detalls',
    'toggle_thumbnails' => 'Commuta les miniatures',
    'details' => 'Detalls',
    'grid_view' => 'Visualització en graella',
    'list_view' => 'Visualització en llista',
    'default' => 'Per defecte',
    'breadcrumb' => 'Ruta de navegació',

    // Header
    'profile_menu' => 'Menú del perfil',
    'view_profile' => 'Mostra el perfil',
    'edit_profile' => 'Edita el perfil',
    'dark_mode' => 'Mode fosc',
    'light_mode' => 'Mode clar',

    // Layout tabs
    'tab_info' => 'Informació',
    'tab_content' => 'Contingut',

    // Email Content
    'email_action_help' => 'Si teniu problemes per fer clic al botó ":actionText", copieu i enganxeu l\'URL següent al vostre navegador web:',
    'email_rights' => 'Tots els drets reservats',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Política de privadesa',
    'terms_of_service' => 'Condicions del servei',
];

==> v21.05.tar.gz: bookstack/resources/lang/ca/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Cancel·la',
    'confirm' => 'D\'acord',
    'back' => 'Enrere',
    'save' => 'Desa',
    'continue' => 'Continua',
    'select' => 'Selecciona',
    'toggle_all' => 'Commuta-ho tot',
    'more' => 'Més',

    // Form Labels
    'name' => 'Nom',
    'description' => 'Descripció',
    'role' => 'Rol',
    'cover_image' => 'Imatge de portada',
    'cover_image_description' => 'Aquesta imatge hauria de fer aproximadament 440x250 px.',
    
    // Actions
    'actions' => 'Accions',
    'view' => 'Visualitza',
    'view_all' => 'Visualitza-ho tot',
    'create' => 'Crea',
    'update' => 'Actualitza',
    'edit' => 'Edita',
    'sort' => 'Ordena',
    'move' => 'Mou',
    'copy' => 'Copia',
    'reply' => 'Respon',
    'delete' => 'Suprimeix',
    'delete_confirm' => 'Confirma la supressió',
    'search' => 'Cerca',
    'search_clear' => 'Esborra la cerca',
    'reset' => 'Reinicialitza',
    'remove' => 'Elimina',
    'add' => 'Afegeix',
    'fullscreen' => 'Pantalla completa',
    'favourite' => 'Favourite',
    'unfavourite' => 'Unfavourite',
    'next' => 'Next',
    'previous' => 'Previous',

    // Sort Options
    'sort_options' => 'Opcions d\'ordenació',
    'sort_direction_toggle' => 'Commuta la direcció de l\'ordenació',
    'sort_ascending' => 'Ordre ascendent',
    'sort_descending' => 'Ordre descendent',
    'sort_name' => 'Nom',
    'sort_default' => 'Per defecte',
    'sort_created_at' => 'Data de creació',
    'sort_updated_at' => 'Data d\'actualització',

    // Misc
    'deleted_user' => 'Usuari eliminat',
    'no_activity' => 'No hi ha activitat',
    'no_items' => 'No hi ha cap element',
    'back_to_top' => 'Torna a dalt',
    'toggle_details' => 'Commuta els detalls',
    'toggle_thumbnails' => 'Commuta les miniatures',
    'details' => 'Detalls',
    'grid_view' => 'Visualització en graella',
    'list_view' => 'Visualització en llista',
    'default' => 'Per defecte',
    'breadcrumb' => 'Ruta de navegació',

    // Header
    'header_menu_expand' => 'Expand Header Menu',
    'profile_menu' => 'Menú del perfil',
    'view_profile' => 'Mostra el perfil',
    'edit_profile' => 'Edita el perfil',
    'dark_mode' => 'Mode fosc',
    'light_mode' => 'Mode clar',

    // Layout tabs
    'tab_info' => 'Informació',
    'tab_info_label' => 'Tab: Show Secondary Information',
    'tab_content' => 'Contingut',
    'tab_content_label' => 'Tab: Show Primary Content',

    // Email Content
    'email_action_help' => 'Si teniu problemes per fer clic al botó ":actionText", copieu i enganxeu l\'URL següent al vostre navegador web:',
    'email_rights' => 'Tots els drets reservats',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Política de privadesa',
    'terms_of_service' => 'Condicions del servei',
];
